@@ -100,12 +100,22 @@ bad:
 
 #ifndef __PYX_HAVE_RT_ImportFunction
 #define __PYX_HAVE_RT_ImportFunction
-static int __Pyx_ImportFunction(PyObject *module, char *funcname, void **f, char *sig) {
+static int __Pyx_ImportFunction(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
+#if PY_VERSION_HEX < 0x02050000
+    char *api = (char *)"__pyx_capi__";
+#else
+    const char *api = "__pyx_capi__";
+#endif
     PyObject *d = 0;
     PyObject *cobj = 0;
-    char *desc;
-    
-    d = PyObject_GetAttrString(module, "__pyx_capi__");
+    const char *desc;
+    const char *s1, *s2;
+    union {
+        void (*fp)(void);
+        void *p;
+    } tmp;
+
+    d = PyObject_GetAttrString(module, api);
     if (!d)
         goto bad;
     cobj = PyDict_GetItemString(d, funcname);
@@ -115,16 +125,19 @@ static int __Pyx_ImportFunction(PyObject *module, char *funcname, void **f, char
                 PyModule_GetName(module), funcname);
         goto bad;
     }
-    desc = (char *)PyCObject_GetDesc(cobj);
+    desc = (const char *)PyCObject_GetDesc(cobj);
     if (!desc)
         goto bad;
-    if (strcmp(desc, sig) != 0) {
+    s1 = desc; s2 = sig;
+    while (*s1 != '\0' && *s1 == *s2) { s1++; s2++; }
+    if (*s1 != *s2) {
         PyErr_Format(PyExc_TypeError,
             "C function %s.%s has wrong signature (expected %s, got %s)",
-                PyModule_GetName(module), funcname, sig, desc);
+             PyModule_GetName(module), funcname, sig, desc);
         goto bad;
     }
-    *f = PyCObject_AsVoidPtr(cobj);
+    tmp.p = PyCObject_AsVoidPtr(cobj);
+    *f = tmp.fp;
     Py_DECREF(d);
     return 0;
 bad:
@@ -184,48 +197,48 @@ static int import_lxml__etree(void) {
   PyObject *module = 0;
   module = __Pyx_ImportModule("lxml.etree");
   if (!module) goto bad;
-  if (__Pyx_ImportFunction(module, "deepcopyNodeToDocument", (void**)&deepcopyNodeToDocument, "struct LxmlElement *(struct LxmlDocument *, xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "elementTreeFactory", (void**)&elementTreeFactory, "struct LxmlElementTree *(struct LxmlElement *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "newElementTree", (void**)&newElementTree, "struct LxmlElementTree *(struct LxmlElement *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "elementFactory", (void**)&elementFactory, "struct LxmlElement *(struct LxmlDocument *, xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "makeElement", (void**)&makeElement, "struct LxmlElement *(PyObject *, struct LxmlDocument *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "makeSubElement", (void**)&makeSubElement, "struct LxmlElement *(struct LxmlElement *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "setElementClassLookupFunction", (void**)&setElementClassLookupFunction, "void (_element_class_lookup_function, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "lookupDefaultElementClass", (void**)&lookupDefaultElementClass, "PyObject *(PyObject *, PyObject *, xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "lookupNamespaceElementClass", (void**)&lookupNamespaceElementClass, "PyObject *(PyObject *, PyObject *, xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "callLookupFallback", (void**)&callLookupFallback, "PyObject *(struct LxmlFallbackElementClassLookup *, struct LxmlDocument *, xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "tagMatches", (void**)&tagMatches, "int (xmlNode *, char *, char *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "documentOrRaise", (void**)&documentOrRaise, "struct LxmlDocument *(PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "rootNodeOrRaise", (void**)&rootNodeOrRaise, "struct LxmlElement *(PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "hasText", (void**)&hasText, "int (xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "hasTail", (void**)&hasTail, "int (xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "textOf", (void**)&textOf, "PyObject *(xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "tailOf", (void**)&tailOf, "PyObject *(xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "setNodeText", (void**)&setNodeText, "int (xmlNode *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "setTailText", (void**)&setTailText, "int (xmlNode *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "attributeValue", (void**)&attributeValue, "PyObject *(xmlNode *, xmlAttr *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "attributeValueFromNsName", (void**)&attributeValueFromNsName, "PyObject *(xmlNode *, char *, char *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "getAttributeValue", (void**)&getAttributeValue, "PyObject *(struct LxmlElement *, PyObject *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "iterattributes", (void**)&iterattributes, "PyObject *(struct LxmlElement *, int)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "collectAttributes", (void**)&collectAttributes, "PyObject *(xmlNode *, int)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "setAttributeValue", (void**)&setAttributeValue, "int (struct LxmlElement *, PyObject *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "delAttribute", (void**)&delAttribute, "int (struct LxmlElement *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "delAttributeFromNsName", (void**)&delAttributeFromNsName, "int (xmlNode *, char *, char *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "hasChild", (void**)&hasChild, "int (xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "findChild", (void**)&findChild, "xmlNode *(xmlNode *, Py_ssize_t)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "findChildForwards", (void**)&findChildForwards, "xmlNode *(xmlNode *, Py_ssize_t)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "findChildBackwards", (void**)&findChildBackwards, "xmlNode *(xmlNode *, Py_ssize_t)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "nextElement", (void**)&nextElement, "xmlNode *(xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "previousElement", (void**)&previousElement, "xmlNode *(xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "appendChild", (void**)&appendChild, "void (struct LxmlElement *, struct LxmlElement *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "pyunicode", (void**)&pyunicode, "PyObject *(char *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "utf8", (void**)&utf8, "PyObject *(PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "getNsTag", (void**)&getNsTag, "PyObject *(PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "namespacedName", (void**)&namespacedName, "PyObject *(xmlNode *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "namespacedNameFromNsName", (void**)&namespacedNameFromNsName, "PyObject *(char *, char *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "iteratorStoreNext", (void**)&iteratorStoreNext, "void (struct LxmlElementIterator *, struct LxmlElement *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "initTagMatch", (void**)&initTagMatch, "void (struct LxmlElementTagMatcher *, PyObject *)") < 0) goto bad;
-  if (__Pyx_ImportFunction(module, "findOrBuildNodeNsPrefix", (void**)&findOrBuildNodeNsPrefix, "xmlNs *(struct LxmlDocument *, xmlNode *, char *, char *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "deepcopyNodeToDocument", (void (**)(void))&deepcopyNodeToDocument, "struct LxmlElement *(struct LxmlDocument *, xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "elementTreeFactory", (void (**)(void))&elementTreeFactory, "struct LxmlElementTree *(struct LxmlElement *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "newElementTree", (void (**)(void))&newElementTree, "struct LxmlElementTree *(struct LxmlElement *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "elementFactory", (void (**)(void))&elementFactory, "struct LxmlElement *(struct LxmlDocument *, xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "makeElement", (void (**)(void))&makeElement, "struct LxmlElement *(PyObject *, struct LxmlDocument *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "makeSubElement", (void (**)(void))&makeSubElement, "struct LxmlElement *(struct LxmlElement *, PyObject *, PyObject *, PyObject *, PyObject *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "setElementClassLookupFunction", (void (**)(void))&setElementClassLookupFunction, "void (_element_class_lookup_function, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "lookupDefaultElementClass", (void (**)(void))&lookupDefaultElementClass, "PyObject *(PyObject *, PyObject *, xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "lookupNamespaceElementClass", (void (**)(void))&lookupNamespaceElementClass, "PyObject *(PyObject *, PyObject *, xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "callLookupFallback", (void (**)(void))&callLookupFallback, "PyObject *(struct LxmlFallbackElementClassLookup *, struct LxmlDocument *, xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "tagMatches", (void (**)(void))&tagMatches, "int (xmlNode *, char *, char *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "documentOrRaise", (void (**)(void))&documentOrRaise, "struct LxmlDocument *(PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "rootNodeOrRaise", (void (**)(void))&rootNodeOrRaise, "struct LxmlElement *(PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "hasText", (void (**)(void))&hasText, "int (xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "hasTail", (void (**)(void))&hasTail, "int (xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "textOf", (void (**)(void))&textOf, "PyObject *(xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "tailOf", (void (**)(void))&tailOf, "PyObject *(xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "setNodeText", (void (**)(void))&setNodeText, "int (xmlNode *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "setTailText", (void (**)(void))&setTailText, "int (xmlNode *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "attributeValue", (void (**)(void))&attributeValue, "PyObject *(xmlNode *, xmlAttr *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "attributeValueFromNsName", (void (**)(void))&attributeValueFromNsName, "PyObject *(xmlNode *, char *, char *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "getAttributeValue", (void (**)(void))&getAttributeValue, "PyObject *(struct LxmlElement *, PyObject *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "iterattributes", (void (**)(void))&iterattributes, "PyObject *(struct LxmlElement *, int)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "collectAttributes", (void (**)(void))&collectAttributes, "PyObject *(xmlNode *, int)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "setAttributeValue", (void (**)(void))&setAttributeValue, "int (struct LxmlElement *, PyObject *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "delAttribute", (void (**)(void))&delAttribute, "int (struct LxmlElement *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "delAttributeFromNsName", (void (**)(void))&delAttributeFromNsName, "int (xmlNode *, char *, char *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "hasChild", (void (**)(void))&hasChild, "int (xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "findChild", (void (**)(void))&findChild, "xmlNode *(xmlNode *, Py_ssize_t)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "findChildForwards", (void (**)(void))&findChildForwards, "xmlNode *(xmlNode *, Py_ssize_t)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "findChildBackwards", (void (**)(void))&findChildBackwards, "xmlNode *(xmlNode *, Py_ssize_t)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "nextElement", (void (**)(void))&nextElement, "xmlNode *(xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "previousElement", (void (**)(void))&previousElement, "xmlNode *(xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "appendChild", (void (**)(void))&appendChild, "void (struct LxmlElement *, struct LxmlElement *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "pyunicode", (void (**)(void))&pyunicode, "PyObject *(char *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "utf8", (void (**)(void))&utf8, "PyObject *(PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "getNsTag", (void (**)(void))&getNsTag, "PyObject *(PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "namespacedName", (void (**)(void))&namespacedName, "PyObject *(xmlNode *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "namespacedNameFromNsName", (void (**)(void))&namespacedNameFromNsName, "PyObject *(char *, char *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "iteratorStoreNext", (void (**)(void))&iteratorStoreNext, "void (struct LxmlElementIterator *, struct LxmlElement *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "initTagMatch", (void (**)(void))&initTagMatch, "void (struct LxmlElementTagMatcher *, PyObject *)") < 0) goto bad;
+  if (__Pyx_ImportFunction(module, "findOrBuildNodeNsPrefix", (void (**)(void))&findOrBuildNodeNsPrefix, "xmlNs *(struct LxmlDocument *, xmlNode *, char *, char *)") < 0) goto bad;
   Py_DECREF(module); module = 0;
   __pyx_ptype_4lxml_5etree__Document = __Pyx_ImportType("lxml.etree", "_Document", sizeof(struct LxmlDocument)); if (!__pyx_ptype_4lxml_5etree__Document) goto bad;
   __pyx_ptype_4lxml_5etree__Element = __Pyx_ImportType("lxml.etree", "_Element", sizeof(struct LxmlElement)); if (!__pyx_ptype_4lxml_5etree__Element) goto bad;
